@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
+from __future__ import absolute_import, unicode_literals
 
-
-
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 from pandas import Index, Series, DataFrame
 
